@@ -125,7 +125,7 @@ static void xmltagstart(XMLParser *, const char *, size_t);
 static void xmltagstartparsed(XMLParser *, const char *, size_t, int);
 
 /* map tag name to TagId type */
-/* RSS, must be alphabetical order */
+/* RSS, keep this in alphabetical order */
 static const FeedTag rsstags[] = {
 	{ STRP("author"),            RSSTagAuthor            },
 	{ STRP("category"),          RSSTagCategory          },
@@ -142,7 +142,7 @@ static const FeedTag rsstags[] = {
 	{ STRP("title"),             RSSTagTitle             }
 };
 
-/* Atom, must be alphabetical order */
+/* Atom, keep this in alphabetical order */
 static const FeedTag atomtags[] = {
 	{ STRP("author"),            AtomTagAuthor           },
 	{ STRP("category"),          AtomTagCategory         },
@@ -212,34 +212,33 @@ static FeedContext ctx;
 static XMLParser parser; /* XML parser state */
 static String attrispermalink, attrrel, attrtype, tmpstr;
 
-static int
-tagcmp(const void *v1, const void *v2)
-{
-	return strcasecmp(((FeedTag *)v1)->name, ((FeedTag *)v2)->name);
-}
-
-/* Unique tagid for parsed tag name. */
+/* Unique tag(id) for parsed tag name. */
 static FeedTag *
 gettag(enum FeedType feedtype, const char *name, size_t namelen)
 {
-	FeedTag f, *r = NULL;
-
-	f.name = (char *)name;
+	FeedTag *r;
+	size_t i;
 
 	switch (feedtype) {
 	case FeedTypeRSS:
-		r = bsearch(&f, rsstags, sizeof(rsstags) / sizeof(rsstags[0]),
-		        sizeof(rsstags[0]), tagcmp);
+		for (i = 0; i < sizeof(rsstags) / sizeof(rsstags[0]); i++) {
+			r = (FeedTag *)&rsstags[i];
+			if (r->len == namelen && !strcasecmp(r->name, name))
+				return r;
+		}
 		break;
 	case FeedTypeAtom:
-		r = bsearch(&f, atomtags, sizeof(atomtags) / sizeof(atomtags[0]),
-		        sizeof(atomtags[0]), tagcmp);
+		for (i = 0; i < sizeof(atomtags) / sizeof(atomtags[0]); i++) {
+			r = (FeedTag *)&atomtags[i];
+			if (r->len == namelen && !strcasecmp(r->name, name))
+				return r;
+		}
 		break;
 	default:
 		break;
 	}
 
-	return r;
+	return NULL;
 }
 
 static char *
