@@ -93,8 +93,8 @@ printfeed(FILE *fp, const char *feedname)
 				fputs("\t<content type=\"html\">", stdout);
 			} else {
 				/* NOTE: an RSS/Atom viewer may or may not format
-				   whitespace such as newlines.
-				   Workaround: type="html" and <![CDATA[<pre></pre>]]> */
+				 * whitespace such as newlines.
+				 * Workaround: type="html" and <![CDATA[<pre></pre>]]> */
 				fputs("\t<content>", stdout);
 			}
 			printcontent(fields[FieldContent]);
