@@ -307,7 +307,7 @@ colw(const char *s)
 }
 
 /* Format `len` columns of characters. If string is shorter pad the rest
-   with characters `pad`. */
+ * with characters `pad`. */
 static int
 utf8pad(char *buf, size_t bufsiz, const char *s, size_t len, int pad)
 {
@@ -590,10 +590,10 @@ processexit(pid_t pid, int interactive)
 }
 
 /* Pipe item line or item field to a program.
-   If `field` is -1 then pipe the TSV line, else a specified field.
-   if `interactive` is 1 then cleanup and restore the tty and wait on the
-   process.
-   if 0 then don't do that and also write stdout and stderr to /dev/null. */
+ * If `field` is -1 then pipe the TSV line, else a specified field.
+ * if `interactive` is 1 then cleanup and restore the tty and wait on the
+ * process.
+ * if 0 then don't do that and also write stdout and stderr to /dev/null. */
 static void
 pipeitem(const char *cmd, struct item *item, int field, int interactive)
 {
@@ -1099,7 +1099,7 @@ statusbar_draw(struct statusbar *s)
 	cursormove(s->x, s->y);
 	THEME_STATUSBAR();
 	/* terminals without xenl (eat newline glitch) mess up scrolling when
-	   using the last cell on the last line on the screen. */
+	 * using the last cell on the last line on the screen. */
 	printutf8pad(stdout, s->text, s->width - (!eat_newline_glitch), ' ');
 	fflush(stdout);
 	attrmode(ATTR_RESET);
@@ -1875,7 +1875,7 @@ markread(struct pane *p, off_t from, off_t to, int isread)
 		_exit(status);
 	default:
 		/* waitpid() and block on process status change,
-		   fail if the exit status code was unavailable or non-zero */
+		 * fail if the exit status code was unavailable or non-zero */
 		if (waitpid(pid, &status, 0) <= 0 || status)
 			break;
 
@@ -2072,9 +2072,9 @@ main(int argc, char *argv[])
 				button &= ~keymask; /* unset key mask */
 
 				/* button numbers (0 - 2) encoded in lowest 2 bits
-				   release does not indicate which button (so set to 0).
-				   Handle extended buttons like scrollwheels
-				   and side-buttons by each range. */
+				 * release does not indicate which button (so set to 0).
+				 * Handle extended buttons like scrollwheels
+				 * and side-buttons by each range. */
 				release = 0;
 				if (button == 3) {
 					button = -1;
@@ -2364,8 +2364,8 @@ event:
 		if (state_sigchld) {
 			state_sigchld = 0;
 			/* wait on child processes so they don't become a zombie,
-			   do not block the parent process if there is no status,
-			   ignore errors */
+			 * do not block the parent process if there is no status,
+			 * ignore errors */
 			while (waitpid((pid_t)-1, NULL, WNOHANG) > 0)
 				;
 		}
