@@ -1,5 +1,3 @@
-#include <sys/types.h>
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -87,10 +85,8 @@ main(int argc, char *argv[])
 
 	if (!(feeds = calloc(argc, sizeof(struct feed))))
 		err(1, "calloc");
-	if ((comparetime = time(NULL)) == (time_t)-1)
-		errx(1, "time");
-	/* 1 day is old news */
-	comparetime -= 86400;
+	if ((comparetime = getcomparetime()) == (time_t)-1)
+		errx(1, "getcomparetime");
 
 	fputs("<!DOCTYPE HTML>\n"
 	      "<html>\n"
