@@ -1,5 +1,3 @@
-#include <sys/types.h>
-
 #include <locale.h>
 #include <stdio.h>
 #include <string.h>
@@ -63,10 +61,8 @@ main(int argc, char *argv[])
 	if (pledge(argc == 1 ? "stdio" : "stdio rpath", NULL) == -1)
 		err(1, "pledge");
 
-	if ((comparetime = time(NULL)) == (time_t)-1)
-		errx(1, "time");
-	/* 1 day is old news */
-	comparetime -= 86400;
+	if ((comparetime = getcomparetime()) == (time_t)-1)
+		errx(1, "getcomparetime");
 
 	if (argc == 1) {
 		printfeed(stdin, "");
