@@ -8,7 +8,7 @@
 #include "util.h"
 
 /* print to stderr, print error message of errno and exit().
-   Unlike BSD err() it does not prefix __progname */
+ * Unlike BSD err() it does not prefix __progname */
 __dead void
 err(int exitstatus, const char *fmt, ...)
 {
@@ -29,7 +29,7 @@ err(int exitstatus, const char *fmt, ...)
 }
 
 /* print to stderr and exit().
-   Unlike BSD errx() it does not prefix __progname */
+ * Unlike BSD errx() it does not prefix __progname */
 __dead void
 errx(int exitstatus, const char *fmt, ...)
 {
@@ -89,7 +89,7 @@ uri_hasscheme(const char *s)
 }
 
 /* Parse URI string `s` into an uri structure `u`.
-   Returns 0 on success or -1 on failure */
+ * Returns 0 on success or -1 on failure */
 int
 uri_parse(const char *s, struct uri *u)
 {
@@ -204,8 +204,8 @@ parsepath:
 }
 
 /* Transform and try to make the URI `u` absolute using base URI `b` into `a`.
-   Follows some of the logic from "RFC 3986 - 5.2.2. Transform References".
-   Returns 0 on success, -1 on error or truncation. */
+ * Follows some of the logic from "RFC 3986 - 5.2.2. Transform References".
+ * Returns 0 on success, -1 on error or truncation. */
 int
 uri_makeabs(struct uri *a, struct uri *u, struct uri *b)
 {
@@ -311,7 +311,7 @@ strtotime(const char *s, time_t *t)
 		return -1;
 
 	/* NOTE: the type long long supports the 64-bit range. If time_t is
-	   64-bit it is "2038-ready", otherwise it is truncated/wrapped. */
+	 * 64-bit it is "2038-ready", otherwise it is truncated/wrapped. */
 	if (t)
 		*t = (time_t)l;
 
