@@ -23,7 +23,7 @@ typedef struct xmlparser {
 
 #ifndef GETNEXT
 	/* GETNEXT overridden to reduce function call overhead and further
-	   context optimizations. */
+	 * context optimizations. */
 	#define GETNEXT getchar_unlocked
 #endif
 
